# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from hassmpris.proto import mpris_pb2 as mpris__pb2


class MPRISStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/MPRIS.MPRIS/Ping',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Updates = channel.unary_stream(
                '/MPRIS.MPRIS/Updates',
                request_serializer=mpris__pb2.MPRISUpdateRequest.SerializeToString,
                response_deserializer=mpris__pb2.MPRISUpdateReply.FromString,
                )
        self.ChangePlayerStatus = channel.unary_unary(
                '/MPRIS.MPRIS/ChangePlayerStatus',
                request_serializer=mpris__pb2.ChangePlayerStatusRequest.SerializeToString,
                response_deserializer=mpris__pb2.ChangePlayerStatusReply.FromString,
                )
        self.PlayerNext = channel.unary_unary(
                '/MPRIS.MPRIS/PlayerNext',
                request_serializer=mpris__pb2.PlayerNextRequest.SerializeToString,
                response_deserializer=mpris__pb2.PlayerNextReply.FromString,
                )
        self.PlayerPrevious = channel.unary_unary(
                '/MPRIS.MPRIS/PlayerPrevious',
                request_serializer=mpris__pb2.PlayerPreviousRequest.SerializeToString,
                response_deserializer=mpris__pb2.PlayerPreviousReply.FromString,
                )


class MPRISServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Updates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePlayerStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayerNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayerPrevious(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MPRISServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Updates': grpc.unary_stream_rpc_method_handler(
                    servicer.Updates,
                    request_deserializer=mpris__pb2.MPRISUpdateRequest.FromString,
                    response_serializer=mpris__pb2.MPRISUpdateReply.SerializeToString,
            ),
            'ChangePlayerStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePlayerStatus,
                    request_deserializer=mpris__pb2.ChangePlayerStatusRequest.FromString,
                    response_serializer=mpris__pb2.ChangePlayerStatusReply.SerializeToString,
            ),
            'PlayerNext': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayerNext,
                    request_deserializer=mpris__pb2.PlayerNextRequest.FromString,
                    response_serializer=mpris__pb2.PlayerNextReply.SerializeToString,
            ),
            'PlayerPrevious': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayerPrevious,
                    request_deserializer=mpris__pb2.PlayerPreviousRequest.FromString,
                    response_serializer=mpris__pb2.PlayerPreviousReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'MPRIS.MPRIS', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MPRIS(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/Ping',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Updates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/MPRIS.MPRIS/Updates',
            mpris__pb2.MPRISUpdateRequest.SerializeToString,
            mpris__pb2.MPRISUpdateReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePlayerStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/ChangePlayerStatus',
            mpris__pb2.ChangePlayerStatusRequest.SerializeToString,
            mpris__pb2.ChangePlayerStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayerNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/PlayerNext',
            mpris__pb2.PlayerNextRequest.SerializeToString,
            mpris__pb2.PlayerNextReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayerPrevious(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/PlayerPrevious',
            mpris__pb2.PlayerPreviousRequest.SerializeToString,
            mpris__pb2.PlayerPreviousReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
